@@ -19,12 +19,14 @@ import errno
 import logging
 import tempfile
 
-from gi.repository import GObject
+from gi.repository import GLib
 
 from sugar3 import env
 
 from carquinyol import layoutmanager
 
+logger = logging.getLogger('filestore')
+
 
 class FileStore(object):
     """Handle the storage of one file per entry.
@@ -55,11 +57,11 @@ class FileStore(object):
 
             if transfer_ownership:
                 try:
-                    logging.debug('FileStore moving from %r to %r', file_path,
-                        destination_path)
+                    logger.debug('FileStore moving from %r to %r', file_path,
+                                  destination_path)
                     os.rename(file_path, destination_path)
                     completion_cb()
-                except OSError, e:
+                except OSError as e:
                     if e.errno == errno.EXDEV:
                         self._async_copy(file_path, destination_path,
                                          completion_cb, unlink_src=True)
@@ -67,27 +69,27 @@ class FileStore(object):
                         raise
             else:
                 self._async_copy(file_path, destination_path, completion_cb,
-                        unlink_src=False)
+                                 unlink_src=False)
             """
         TODO: How can we support deleting the file of an entry?
         elif not file_path and os.path.exists(destination_path):
-            logging.debug('FileStore: deleting %r' % destination_path)
+            logger.debug('FileStore: deleting %r' % destination_path)
             os.remove(destination_path)
             completion_cb()
             """
         else:
-            logging.debug('FileStore: Nothing to do')
+            logger.debug('FileStore: Nothing to do')
             completion_cb()
 
     def _async_copy(self, file_path, destination_path, completion_cb,
-            unlink_src):
+                    unlink_src):
         """Start copying a file asynchronously.
 
         """
-        logging.debug('FileStore copying from %r to %r', file_path,
-            destination_path)
+        logger.debug('FileStore copying from %r to %r', file_path,
+                      destination_path)
         async_copy = AsyncCopy(file_path, destination_path, completion_cb,
-                unlink_src)
+                               unlink_src)
         async_copy.start()
 
     def retrieve(self, uid, user_id, extension):
@@ -98,16 +100,20 @@ class FileStore(object):
         """
         file_path = layoutmanager.get_instance().get_data_path(uid)
         if not os.path.exists(file_path):
-            logging.debug('Entry %r doesnt have any file', uid)
+            logger.debug('Entry %r doesnt have any file', uid)
             return ''
 
         use_instance_dir = os.path.exists('/etc/olpc-security') and \
-                           os.getuid() != user_id
+            os.getuid() != user_id
         if use_instance_dir:
             if not user_id:
                 raise ValueError('Couldnt determine the current user uid.')
-            destination_dir = os.path.join(os.environ['HOME'], 'isolation',
-                '1', 'uid_to_instance_dir', str(user_id))
+            destination_dir = os.path.join(
+                os.environ['HOME'],
+                'isolation',
+                '1',
+                'uid_to_instance_dir',
+                str(user_id))
         else:
             destination_dir = env.get_profile_path('data')
             if not os.path.exists(destination_dir):
@@ -118,8 +124,8 @@ class FileStore(object):
         elif extension:
             extension = '.' + extension
 
-        fd, destination_path = tempfile.mkstemp(prefix=uid + '_',
-                suffix=extension, dir=destination_dir)
+        fd, destination_path = tempfile.mkstemp(
+            prefix=uid + '_', suffix=extension, dir=destination_dir)
         os.close(fd)
         os.unlink(destination_path)
 
@@ -127,7 +133,7 @@ class FileStore(object):
         # fail if the file is in a different filesystem. Do a symlink instead.
         try:
             os.link(file_path, destination_path)
-        except OSError, e:
+        except OSError as e:
             if e.errno == errno.EXDEV:
                 os.symlink(file_path, destination_path)
             else:
@@ -151,10 +157,10 @@ class FileStore(object):
             existing_uid)
         new_file = layoutmanager.get_instance().get_data_path(new_uid)
 
-        logging.debug('removing %r', new_file)
+        logger.debug('removing %r', new_file)
         os.remove(new_file)
 
-        logging.debug('hard linking %r -> %r', new_file, existing_file)
+        logger.debug('hard linking %r -> %r', new_file, existing_file)
         os.link(existing_file, new_file)
 
 
@@ -186,10 +192,10 @@ class AsyncCopy(object):
 
             # error writing data to file?
             if count < len(data):
-                logging.error('AC: Error writing %s -> %s: wrote less than '
-                        'expected', self.src, self.dest)
+                logger.error('AC: Error writing %s -> %s: wrote less than '
+                              'expected', self.src, self.dest)
                 self._complete(RuntimeError(
-                        'Error writing data to destination file'))
+                    'Error writing data to destination file'))
                 return False
 
             # FIXME: emit progress here
@@ -198,9 +204,9 @@ class AsyncCopy(object):
             if len(data) < AsyncCopy.CHUNK_SIZE:
                 self._complete(None)
                 return False
-        except Exception, err:
-            logging.error('AC: Error copying %s -> %s: %r', self.src, self.
-                dest, err)
+        except Exception as err:
+            logger.error('AC: Error copying %s -> %s: %r', self.src, self.
+                          dest, err)
             self._complete(err)
             return False
 
@@ -218,9 +224,9 @@ class AsyncCopy(object):
 
         self.src_fp = os.open(self.src, os.O_RDONLY)
         self.dest_fp = os.open(self.dest, os.O_RDWR | os.O_TRUNC | os.O_CREAT,
-                0444)
+                               0o444)
 
         stat = os.fstat(self.src_fp)
         self.size = stat[6]
 
-        GObject.idle_add(self._copy_block)
+        GLib.idle_add(self._copy_block)
